package com.landray.kmss.sys.attachment.actions;

import com.landray.kmss.web.config.IActionConfig;
import java.util.Map;
import com.landray.kmss.common.service.IBaseService;
import com.landray.kmss.web.config.ForwardConfig;
import java.util.List;
import com.landray.kmss.util.HQLUtil;
import java.util.Arrays;
import org.springframework.util.StringUtils;
import com.landray.kmss.sys.attachment.model.SysAttPlayLogConfig;
import com.sunbor.web.tag.Page;
import com.landray.kmss.sys.log.util.UserOperHelper;
import com.landray.kmss.sys.language.utils.SysLangUtil;
import com.landray.kmss.common.forms.IExtendForm;
import com.landray.kmss.sys.config.model.SysConfigParameters;
import com.landray.kmss.util.HQLHelper;
import com.landray.kmss.common.dao.HQLInfo;
import com.landray.kmss.sys.attachment.forms.SysAttPlayLogForm;
import com.landray.kmss.sys.attachment.model.SysAttPlayLog;
import com.landray.kmss.util.KmssReturnPage;
import com.landray.kmss.sys.attachment.service.spring.SysAttPlayLogTypeFactory;
import net.sf.json.JSONObject;
import com.landray.kmss.common.exception.NoRecordException;
import com.landray.kmss.util.StringUtil;
import com.landray.kmss.common.exception.UnexpectedRequestException;
import com.landray.kmss.util.KmssMessages;
import com.landray.kmss.common.test.TimeCounter;
import com.landray.kmss.web.action.ActionForward;
import javax.servlet.http.HttpServletResponse;
import com.landray.kmss.web.action.ActionForm;
import com.landray.kmss.web.action.ActionMapping;
import javax.servlet.http.HttpServletRequest;
import com.landray.kmss.sys.attachment.service.ISysAttPlayLogService;
import com.landray.kmss.common.actions.ExtendAction;

public class SysAttPlayLogAction extends ExtendAction
{
    private ISysAttPlayLogService sysAttPlayLogService;
    
    public ISysAttPlayLogService getServiceImp(final HttpServletRequest request) {
        if (this.sysAttPlayLogService == null) {
            this.sysAttPlayLogService = (ISysAttPlayLogService)this.getBean("sysAttPlayLogService");
        }
        return this.sysAttPlayLogService;
    }
    
    public ActionForward viewByAttId(final ActionMapping mapping, final ActionForm form, final HttpServletRequest request, final HttpServletResponse response) throws Exception {
        TimeCounter.logCurrentTime("Action-viewByAttId", true, (Class)this.getClass());
        final KmssMessages messages = new KmssMessages();
        try {
            if (!"GET".equals(request.getMethod())) {
                throw new UnexpectedRequestException();
            }
            final String fdAttId = request.getParameter("fdAttId");
            final String fdType = request.getParameter("fdType");
            if (StringUtil.isNull(fdAttId) || StringUtil.isNull(fdType)) {
                messages.addError((Throwable)new NoRecordException());
            }
            else {
                final JSONObject source = new JSONObject();
                final Boolean isEnable = SysAttPlayLogTypeFactory.isEnable(fdType);
                if (isEnable) {
                    final SysAttPlayLog log = this.getServiceImp(request).viewByAttId(fdAttId);
                    if (log != null) {
                        source.element("fdId", (Object)log.getFdId());
                        source.element("fdParam", (Object)log.getFdParam());
                    }
                }
                source.element("fdEnable", (Object)isEnable);
                request.setAttribute("lui-source", (Object)source);
            }
        }
        catch (final Exception e) {
            messages.addError((Throwable)e);
        }
        KmssReturnPage.getInstance(request).addMessages(messages).addButton(0).save(request);
        TimeCounter.logCurrentTime("Action-viewByAttId", false, (Class)this.getClass());
        if (messages.hasError()) {
            return this.getActionForward("failure", mapping, form, request, response);
        }
        return this.getActionForward("lui-source", mapping, form, request, response);
    }
    
    public ActionForward update(final ActionMapping mapping, final ActionForm form, final HttpServletRequest request, final HttpServletResponse response) throws Exception {
        TimeCounter.logCurrentTime("Action-update", true, (Class)this.getClass());
        final KmssMessages messages = new KmssMessages();
        try {
            if (!"POST".equals(request.getMethod())) {
                throw new UnexpectedRequestException();
            }
            final SysAttPlayLogForm logForm = (SysAttPlayLogForm)form;
            this.getServiceImp(request).updateParam(logForm.getFdId(), logForm.getFdParam());
            final JSONObject source = new JSONObject();
            request.setAttribute("lui-source", (Object)source);
        }
        catch (final Exception e) {
            messages.addError((Throwable)e);
        }
        KmssReturnPage.getInstance(request).addMessages(messages).addButton(0).save(request);
        TimeCounter.logCurrentTime("Action-update", false, (Class)this.getClass());
        if (messages.hasError()) {
            return this.getActionForward("failure", mapping, form, request, response);
        }
        return this.getActionForward("lui-source", mapping, form, request, response);
    }
    
    public ActionForward save(final ActionMapping mapping, final ActionForm form, final HttpServletRequest request, final HttpServletResponse response) throws Exception {
        TimeCounter.logCurrentTime("Action-update", true, (Class)this.getClass());
        final KmssMessages messages = new KmssMessages();
        try {
            if (!"POST".equals(request.getMethod())) {
                throw new UnexpectedRequestException();
            }
            final SysAttPlayLogForm logForm = (SysAttPlayLogForm)form;
            final String fdId = this.getServiceImp(request).addParam(logForm.getFdAttId(), logForm.getFdParam(), logForm.getFdType());
            final JSONObject source = new JSONObject();
            if (StringUtil.isNotNull(fdId)) {
                source.element("fdId", (Object)fdId);
            }
            request.setAttribute("lui-source", (Object)source);
        }
        catch (final Exception e) {
            messages.addError((Throwable)e);
        }
        KmssReturnPage.getInstance(request).addMessages(messages).addButton(0).save(request);
        TimeCounter.logCurrentTime("Action-update", false, (Class)this.getClass());
        if (messages.hasError()) {
            return this.getActionForward("failure", mapping, form, request, response);
        }
        return this.getActionForward("lui-source", mapping, form, request, response);
    }
    
    public void changeFindPageHQLInfo(final HttpServletRequest request, final HQLInfo hqlInfo) throws Exception {
        HQLHelper.by(request).buildHQLInfo(hqlInfo, (Class)SysAttPlayLog.class);
        hqlInfo.setOrderBy(this.getFindPageOrderBy(request, hqlInfo.getOrderBy()));
    }
    
    public ActionForward list(final ActionMapping mapping, final ActionForm form, final HttpServletRequest request, final HttpServletResponse response) throws Exception {
        TimeCounter.logCurrentTime("Action-list", true, (Class)this.getClass());
        final KmssMessages messages = new KmssMessages();
        try {
            final String s_pageno = request.getParameter("pageno");
            final String s_rowsize = request.getParameter("rowsize");
            String orderby = request.getParameter("orderby");
            final String ordertype = request.getParameter("ordertype");
            boolean isReserve = false;
            if (ordertype != null && "down".equalsIgnoreCase(ordertype)) {
                isReserve = true;
            }
            int pageno = 0;
            int rowsize = SysConfigParameters.getRowSize();
            if (s_pageno != null && s_pageno.length() > 0 && Integer.parseInt(s_pageno) > 0) {
                pageno = Integer.parseInt(s_pageno);
            }
            if (s_rowsize != null && s_rowsize.length() > 0 && Integer.parseInt(s_rowsize) > 0) {
                rowsize = Integer.parseInt(s_rowsize);
            }
            if (StringUtil.isNotNull(orderby) && form instanceof IExtendForm) {
                final Class<?> modelClass = ((IExtendForm)form).getModelClass();
                if (modelClass != null) {
                    final String langFieldName = SysLangUtil.getLangFieldName(modelClass.getName(), orderby);
                    if (StringUtil.isNotNull(langFieldName)) {
                        orderby = langFieldName;
                    }
                }
            }
            if (isReserve) {
                orderby = String.valueOf(orderby) + " desc";
            }
            final HQLInfo hqlInfo = new HQLInfo();
            hqlInfo.setOrderBy(orderby);
            hqlInfo.setPageNo(pageno);
            hqlInfo.setRowSize(rowsize);
            this.changeFindPageHQLInfo(request, hqlInfo);
            this.filterConfigByListData(hqlInfo);
            final Page page = this.getServiceImp(request).findPage(hqlInfo);
            UserOperHelper.logFindAll(page.getList(), this.getServiceImp(request).getModelName());
            request.setAttribute("queryPage", (Object)page);
        }
        catch (final Exception e) {
            messages.addError((Throwable)e);
        }
        TimeCounter.logCurrentTime("Action-list", false, (Class)this.getClass());
        if (messages.hasError()) {
            KmssReturnPage.getInstance(request).addMessages(messages).addButton(0).save(request);
            return this.getActionForward("failure", mapping, form, request, response);
        }
        return this.getActionForward("list", mapping, form, request, response);
    }
    
    private void filterConfigByListData(final HQLInfo hqlInfo) {
        final String asposeStr = "kmss.sys.attachment.play.log.office.aspose.enabled";
        final String videoStr = "kmss.sys.attachment.play.log.video.enabled";
        final String audioStr = "kmss.sys.attachment.play.log.audio.enabled";
        final SysAttPlayLogConfig sysAttPlayLogConfig = SysAttPlayLogConfig.newInstance();
        final String aspose = sysAttPlayLogConfig.getValue(asposeStr);
        final String video = sysAttPlayLogConfig.getValue(videoStr);
        final String audio = sysAttPlayLogConfig.getValue(audioStr);
        final StringBuilder whereBuilder = new StringBuilder();
        if (StringUtil.isNotNull(aspose) && "false".equals(aspose)) {
            whereBuilder.append("office.aspose").append(",");
        }
        if (StringUtil.isNotNull(video) && "false".equals(video)) {
            whereBuilder.append("video").append(",");
        }
        if (StringUtil.isNotNull(audio) && "false".equals(audio)) {
            whereBuilder.append("audio").append(",");
        }
        String whereBlock = hqlInfo.getWhereBlock();
        String scoreBlock = "";
        if (!StringUtils.isEmpty((Object)whereBuilder.toString())) {
            final String[] fdTypes = whereBuilder.toString().split(",");
            final List<String> list = Arrays.asList(fdTypes);
            scoreBlock = HQLUtil.buildLogicIN("sysAttPlayLog.fdType not", (List)list);
        }
        whereBlock = StringUtil.linkString(whereBlock, " and ", scoreBlock);
        hqlInfo.setWhereBlock(whereBlock);
    }
}
